
# -*- coding: utf-8 -*-

# DO NOT EDIT THIS FILE!
# This file has been autogenerated by dephell <3
# https://github.com/dephell/dephell
#
# dephell deps convert --from-format=poetry --from-path=pyproject.toml --to-format=setuppy --to-path=debian/setup.py

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

readme = ''

setup(
    long_description=readme,
    name='py7zr',
    version='0.0.0',
    packages=['py7zr'],
    package_dir={"": "."},
    package_data={},
    install_requires=[],
)
